#
# spec file for package libmusicbrainz
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libmusicbrainz
Version:        5.1.0
Release:        1.10
Summary:        Library That Provides Access to the MusicBrainz Server
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            http://musicbrainz.org/doc/libmusicbrainz
Source0:        https://github.com/metabrainz/libmusicbrainz/releases/download/release-%{version}/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
# PATCH-FIX-UPSTREAM musicbrainz-cmake-noglob.patch dimstar@opensuse.org -- do not use wildcards for dependencies
Patch0:         musicbrainz-cmake-noglob.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  neon-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libxml-2.0)

%description
MusicBrainz is the second generation incarnation of the CD Index. This
server is designed to enable audio CD, MP3 and Vorbis players to
download metadata about the music they are playing.

%package -n libmusicbrainz5-1
Summary:        Library That Provides Access to the MusicBrainz Server
Group:          System/Libraries

%description -n libmusicbrainz5-1
MusicBrainz is the second generation incarnation of the CD Index. This
server is designed to enable audio CD, MP3 and Vorbis players to
download metadata about the music they are playing.

%package devel
Summary:        Library That Provides Access to the MusicBrainz Server
Group:          Development/Libraries/C and C++
Requires:       libmusicbrainz5-1 = %{version}
Requires:       libstdc++-devel
Provides:       libmusicbrainz5-devel = %{version}-%{release}
Obsoletes:      libmusicbrainz5-devel < %{version}-%{release}

%description devel
MusicBrainz is the second generation incarnation of the CD Index. This
server is designed to enable audio CD, MP3 and Vorbis players to
download metadata about the music they are playing.

%prep
%autosetup -n %{name}-%{version} -p1

%build
CFLAGS="%{optflags} -D_FILE_OFFSET_BITS=64"
CXXFLAGS="%{optflags} -D_FILE_OFFSET_BITS=64 -fvisibility-inlines-hidden"
%cmake
make %{?_smp_mflags} VERBOSE=1

%install
%cmake_install

%post -n libmusicbrainz5-1 -p /sbin/ldconfig
%postun -n libmusicbrainz5-1 -p /sbin/ldconfig

%files -n libmusicbrainz5-1
%license COPYING.txt
%doc AUTHORS.txt NEWS.txt README.md
%{_libdir}/libmusicbrainz5.so.[0-9]*

%files devel
%doc examples/*.cc examples/*.c
%{_includedir}/musicbrainz5/
%{_libdir}/libmusicbrainz5.so
%{_libdir}/pkgconfig/libmusicbrainz5.pc

%changelog
* Sat Jul 10 2021 Dave Plater <davejplater@gmail.com>
- Copied libmusicbrainz5 package and fixed spec file to fix factory
  build failure. Deleted obsolete libmusicbrainz-2.1.5-gcc43.patch
  and gcc6-fix-errors.patch
* Fri Mar 27 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Add musicbrainz-cmake-noglob.patch: do not use wildcards for
  dependencies. Fixes build when using ninja.
* Tue Sep 18 2018 Tomáš Chvátal <tchvatal@suse.com>
- Switch to %%cmake macros
- Drop the test phase, it does nothing it just compiles file that
  can communicate with the musicbrainz server, which can't be
  validated in OBS
* Thu Feb  5 2015 p.drouand@gmail.com
- Update to version 5.1.0
  * Fix LMB-33 - Handle 'ended' element in 'relation'
  * Fix LMB-34 - Remove non-free XML parser and replace with libxml2
  * Add support for cross-compilation and building out of tree
- Add pkgconfig(libxml-2.0) build requires; new upstream dependency
- Bump so version to 5-1
- Delete 0001-Correct-inconsistent-licensing-text.patch
* Sat Oct 11 2014 crrodriguez@opensuse.org
- Build the shared library with -fvisibility-inlines-hidden
* Wed Sep 12 2012 ohering@suse.de
- Correct inconsistent licensing text (bnc#779931)
* Sun Jun 10 2012 ohering@suse.de
- Update to 5.0.1
  Fix LMB-32 - Correctly ignore unrecognised nodes
  Don't compile using -Werror when building from tarball
* Wed May 16 2012 ohering@suse.de
- Update to 5.0.0
  Deprecated functions removed
* Wed May 16 2012 ohering@suse.de
- Update to 4.0.2
  Add extra attributes to Alias
  Add IPI lists to Artist and Label
  Add 'Ended' to Lifespan
  Add PrimaryType and SecondaryTypeList to ReleaseGroup
  Add text based track number to Track
  Add ISWC list to Work
  Debug builds show queries and responses on stderr
  Documentation updates
* Wed May  2 2012 ohering@suse.de
- Update to 4.0.1
  Fixed bug LMB-30 - Unable to access all relation lists on objects with multiple relation lists
  Fixed bug LMB-31 - mb_relationlist_get_targettype always returns "target-type"
* Sat Mar 24 2012 dimstar@opensuse.org
- Add libmusicbrainz4-gcc47.patch: Fix build with gcc 4.7.
* Sun Feb 26 2012 vuntz@opensuse.org
- Cleanup for inclusion in Factory:
  + Add copyright header.
  + Drop libmusicbrainz4-trunk.patch and
    libmusicbrainz4-update-trunk-patch.sh: remove setup to add
    patch for trunk, since it's unused, and I don't think it's
    needed anymore.
  + Remove libmusicbrainz4 Provides from libmusicbrainz4-3: there
    is already a libmusicbrainz4 binary package (from an earlier
    version of libmusicbrainz; because of the shared library
    packaging policy), and that would just create some confusion.
  + Fix baselibs.conf.
  + Run spec-cleaner.
* Tue Jan 17 2012 ohering@suse.de
- Update to 4.0.0
  Added support for collection list being returned as part of a release
* Wed Aug 10 2011 ohering@suse.de
- New version libmusicbrainz-4.0.0beta2
